@@ -8,13 +8,12 @@ const Main = imports.ui.main;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 
-const Gettext = imports.gettext.domain('gnome-shell-extensions');
-const _ = Gettext.gettext;
-const N_ = x => x;
-
 const Me = ExtensionUtils.getCurrentExtension();
 const PlaceDisplay = Me.imports.placeDisplay;
 
+const _ = ExtensionUtils.gettext;
+const N_ = x => x;
+
 const PLACE_ICON_SIZE = 16;
 
 var PlaceMenuItem = GObject.registerClass(
@@ -88,15 +87,12 @@ class PlacesMenu extends PanelMenu.Button {
     _init() {
         super._init(0.0, _('Places'));
 
-        let hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
         let label = new St.Label({
             text: _('Places'),
             y_expand: true,
             y_align: Clutter.ActorAlign.CENTER,
         });
-        hbox.add_child(label);
-        hbox.add_child(PopupMenu.arrowIcon(St.Side.BOTTOM));
-        this.add_actor(hbox);
+        this.add_actor(label);
 
         this.placesManager = new PlaceDisplay.PlacesManager();
 
@@ -136,12 +132,14 @@ class PlacesMenu extends PanelMenu.Button {
     }
 });
 
+/** */
 function init() {
     ExtensionUtils.initTranslations();
 }
 
 let _indicator;
 
+/** */
 function enable() {
     _indicator = new PlacesMenu();
 
@@ -151,6 +149,7 @@ function enable() {
     Main.panel.addToStatusArea('places-menu', _indicator, pos, 'left');
 }
 
+/** */
 function disable() {
     _indicator.destroy();
 }
